require 'thor'
require 'awesome_print'
require 'colorize'
require 'aws-sdk-core'
require 'yaml'
require 'customresource/route53/version'
require 'aws/ec2/instance_data'

module CustomResource
  module Route53

    class Cli < Thor
      class_option :verbose,      :type => :boolean
      class_option :debug,        :type => :boolean
      class_option :trace,        :type => :boolean
      class_option :log_level,    :type => :string, :banner => 'Log level ([:trace, :debug, :info, :step, :warn, :error, :fatal, :todo])'
      class_option :log_file,     :type => :string
      class_option :inifile,      :type => :string
      class_option :input,        :type => :string
      class_option :ip_address,   :type => :string

      no_commands do

        require 'dldinternet/mixlib/thor/no_commands'
        include DLDInternet::MixLib::Thor::No_Commands

        require 'customresource/route53/mixins/cli'
        include CustomResource::Route53::MixIns::Cli

        require 'customresource/route53/mixins/actions'
        include CustomResource::Route53::MixIns::Actions

      end # no_commands

      def initialize(args = [], local_options = {}, config = {})
        super(args,local_options,config)
        @log_level = :step
      end

      desc 'version', 'display current version'
      def version()
        puts ::CustomResource::Route53::VERSION
        exit 0
      end

      desc 'privatehostedzone', 'CRUD for privatehostedzones'
      def privatehostedzone()
        process('PrivateHostedZones')
      end

      desc 'reversednsentry', 'CRUD for reversednsentries'
      def reversednsentry()
        process('ReverseDNSEntries')
      end

    end
  end
end

